==> qgbot-1.1.2.tar.gz: qgbot-1.1.2/src/qgbot/__init__.py <==
"""
Quant-GridBot

====================================
Quant-Grade Dynamic Ethereum Grid & Portfolio Balancing Bot
====================================

Description:
------------
Quant-GridBot is a modular, production-grade Ethereum trading system 
designed for intelligent dynamic grid trading and portfolio rebalancing 
based on live volatility and liquidity conditions. 
It interacts directly with Ethereum nodes (RPC) and performs fully signed, 
gas-optimized Uniswap transactions without relying on external heavy libraries.

Key Features:
-------------
- **Dynamic Adaptive Clustered Grid Strategy** (live volatility detection)
- **Real-Time Dual-Grid Recenter** based on market clustering
- **Portfolio Rebalancer**: Live ETH/Token ratio maintenance
- **Direct Ethereum TX Building, RLP Signing, and Broadcasting** (No `web3.py`)
- **Intelligent Token Selection** based on real-time volatility scoring
- **Persistent SQLite Trade Logging** (thread-safe)
- **Fully Modular and Extensible Codebase**
- **CLI Launchable** with `quantgridbot`
- **Supports Simulation Mode** (`simulate=True`) and Real Trading Mode
- **Graceful Shutdown** (SIGINT/SIGTERM Safe)

Exposed Modules:
-----------------
- `MasterController` (core): Boots wallet, executor, bots
- `GridBot` (grid): Adaptive ETH price grid trading with clustering
- `RebalanceBot` (rebalance): Live portfolio monitoring and corrective rebalancing
- `TradeExecutor` (executor): Transaction builder, signer, and submitter
- `DynamicWallet` (wallet): Real-time portfolio tracking
- `TokenScorer` (scorer): Token volatility analyzer
- `utils`: Ethereum RPC tools, signing helpers, encoding
- `TradeDatabase` (db): SQLite trade persistence

Configuration:
---------------
Requires a `config.json` in the root or execution directory.

Important fields:
    - `rpc_url`: Ethereum RPC endpoint URL
    - `wallet_address`: Your Ethereum wallet public address
    - `private_key`: Private key (hex, NEVER expose)
    - `simulate`: (bool) True for dry-run, False for live trading
    - `trade_volume`: Amount of ETH to trade per grid hit
    - `slippage_pct`: Maximum allowed slippage for executions
    - `grid_lower_pct`, `grid_upper_pct`: Grid width bounds
    - `grid_size`: Number of grid levels
    - `trade_cooldown`: Seconds between allowed trades
    - `refresh_interval`: Seconds between price checks
    - `target_tokens`: ERC20 token addresses for scoring/rebalancing
    - `stablecoin_address`: Stablecoin address for ETH->Stable swaps
    - `min_tokens_out`: Minimum output tolerance for swaps

Entry Point:
------------
- `AppRunner` (runner.py) — initializes entire system
- Launch with: `$ quantgridbot`

Version:
--------
- 1.1.2

Author:
-------
- LoQiseaking69
- Contact: REEL0112359.13@proton.me
"""

__version__ = "1.1.1"
__author__ = "LoQiseaking69"
__email__ = "REEL0112359.13@proton.me"

# === Core System ===
from .core import (
    MasterController,
    MasterController.start_all,
    MasterController.stop_all,
)

# === GridBot Module ===
from .grid import (
    GridBot,
    GridBot.stop,
    GridBot.setup_single_grid,
    GridBot.setup_dual_grids,
    GridBot.detect_clusters,
    GridBot.recenter_grids,
    GridBot.check_grids,
    GridBot.run,
)

# === RebalanceBot Module ===
from .rebalance import (
    RebalanceBot,
    RebalanceBot.stop,
    RebalanceBot.run,
)

# === Trade Execution Module ===
from .executor import (
    TradeExecutor,
    TradeExecutor.sign_tx,
    TradeExecutor.send_tx,
    TradeExecutor.execute_trade,
    TradeExecutor.swap_to_eth,
    TradeExecutor.swap_eth_to_stable,
)

# === Wallet Module ===
from .wallet import (
    DynamicWallet,
    DynamicWallet.fetch_live_tokens,
    DynamicWallet._empty_portfolio,
)

# === Token Scoring Module ===
from .scorer import (
    TokenScorer,
    TokenScorer.fetch_price,
    TokenScorer.score_tokens,
    TokenScorer.best_token,
    TokenScorer.top_n_tokens,
)

# === Ethereum Utility Functions ===
from .utils import (
    set_config,
    require_config,
    safe_rpc,
    keccak,
    rlp_encode,
    now_price,
    get_eth_balance,
    get_gas_price,
    get_nonce,
    eth_to_tokens,
    tokens_to_eth,
)

# === Trade Logging Database ===
from .db import (
    TradeDatabase,
    TradeDatabase.log_trade,
    TradeDatabase.close,
)

==> qgbot-1.1.4.tar.gz: qgbot-1.1.4/src/qgbot/__init__.py <==
"""
Quant-GridBot

====================================
Quant-Grade Dynamic Ethereum Grid & Portfolio Balancing Bot
====================================

Description:
------------
Quant-GridBot is a modular, production-grade Ethereum trading system 
designed for intelligent dynamic grid trading and portfolio rebalancing 
based on live volatility and liquidity conditions. 
It interacts directly with Ethereum nodes (RPC) and performs fully signed, 
gas-optimized Uniswap transactions without relying on external heavy libraries.

Key Features:
-------------
- **Dynamic Adaptive Clustered Grid Strategy** (live volatility detection)
- **Real-Time Dual-Grid Recenter** based on market clustering
- **Portfolio Rebalancer**: Live ETH/Token ratio maintenance
- **Direct Ethereum TX Building, RLP Signing, and Broadcasting** (No `web3.py`)
- **Intelligent Token Selection** based on real-time volatility scoring
- **Persistent SQLite Trade Logging** (thread-safe)
- **Fully Modular and Extensible Codebase**
- **CLI Launchable** with `quantgridbot`
- **Supports Simulation Mode** (`simulate=True`) and Real Trading Mode
- **Graceful Shutdown** (SIGINT/SIGTERM Safe)

Exposed Modules:
-----------------
- `MasterController` (core): Boots wallet, executor, bots
- `GridBot` (grid): Adaptive ETH price grid trading with clustering
- `RebalanceBot` (rebalance): Live portfolio monitoring and corrective rebalancing
- `TradeExecutor` (executor): Transaction builder, signer, and submitter
- `DynamicWallet` (wallet): Real-time portfolio tracking
- `TokenScorer` (scorer): Token volatility analyzer
- `utils`: Ethereum RPC tools, signing helpers, encoding
- `TradeDatabase` (db): SQLite trade persistence

Configuration:
---------------
Requires a `config.json` in the root or execution directory.

Important fields:
    - `rpc_url`: Ethereum RPC endpoint URL
    - `wallet_address`: Your Ethereum wallet public address
    - `private_key`: Private key (hex, NEVER expose)
    - `simulate`: (bool) True for dry-run, False for live trading
    - `trade_volume`: Amount of ETH to trade per grid hit
    - `slippage_pct`: Maximum allowed slippage for executions
    - `grid_lower_pct`, `grid_upper_pct`: Grid width bounds
    - `grid_size`: Number of grid levels
    - `trade_cooldown`: Seconds between allowed trades
    - `refresh_interval`: Seconds between price checks
    - `target_tokens`: ERC20 token addresses for scoring/rebalancing
    - `stablecoin_address`: Stablecoin address for ETH->Stable swaps
    - `min_tokens_out`: Minimum output tolerance for swaps

Entry Point:
------------
- `AppRunner` (runner.py) — initializes entire system
- Launch with: `$ quantgridbot`

Version:
--------
- 1.1.4

Author:
-------
- LoQiseaking69
- Contact: REEL0112359.13@proton.me
"""

__version__ = "1.1.4"
__author__ = "LoQiseaking69"
__email__ = "REEL0112359.13@proton.me"

from .core import MasterController
from .grid import GridBot
from .rebalance import RebalanceBot
from .executor import TradeExecutor
from .wallet import DynamicWallet
from .scorer import TokenScorer
from .db import TradeDatabase
from .utils import (
    safe_rpc, keccak, rlp_encode, now_price,
    get_eth_balance, get_gas_price, get_nonce,
    eth_to_tokens, tokens_to_eth
)
